.. _vlbi_base:

*********
VLBI Base
*********

Routines on which the readers and writers for specific VLBI formats
are based.

Reference/API
=============

.. automodapi:: baseband.vlbi_base
.. automodapi:: baseband.vlbi_base.header
.. automodapi:: baseband.vlbi_base.payload
.. automodapi:: baseband.vlbi_base.frame
.. automodapi:: baseband.vlbi_base.base
.. automodapi:: baseband.vlbi_base.encoding
   :include-all-objects:
.. automodapi:: baseband.vlbi_base.utils

